summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/pushbutton.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/pushbutton.h')
-rw-r--r--kalarm/lib/pushbutton.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kalarm/lib/pushbutton.h b/kalarm/lib/pushbutton.h
index 8d82ac96..615ea10c 100644
--- a/kalarm/lib/pushbutton.h
+++ b/kalarm/lib/pushbutton.h
@@ -34,29 +34,30 @@
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class PushButton : public QPushButton
+class PushButton : public TQPushButton
{
Q_OBJECT
- Q_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly)
+ TQ_OBJECT
+ TQ_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly)
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit PushButton(TQWidget* parent, const char* name = 0);
+ explicit PushButton(TQWidget* tqparent, const char* name = 0);
/** Constructor for a push button which displays a text.
* @param text The text to show on the button.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- PushButton(const TQString& text, TQWidget* parent, const char* name = 0);
+ PushButton(const TQString& text, TQWidget* tqparent, const char* name = 0);
/** Constructor for a push button which displays an icon and a text.
* @param icon The icon to show on the button.
* @param text The text to show on the button.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- PushButton(const TQIconSet& icon, const TQString& text, TQWidget* parent, const char* name = 0);
+ PushButton(const TQIconSet& icon, const TQString& text, TQWidget* tqparent, const char* name = 0);
/** Sets whether the push button is read-only for the user.
* @param readOnly True to set the widget read-only, false to enable its action.
*/
@@ -70,7 +71,7 @@ class PushButton : public QPushButton
virtual void keyPressEvent(TQKeyEvent*);
virtual void keyReleaseEvent(TQKeyEvent*);
private:
- TQWidget::FocusPolicy mFocusPolicy; // default focus policy for the QPushButton
+ TQWidget::FocusPolicy mFocusPolicy; // default focus policy for the TQPushButton
bool mReadOnly; // value cannot be changed
};
@@ -34,29 +34,30 @@
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -34,29 +34,30 @@
/** Constructor for a push button which displays a text.
* @param text The text to show on the button.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -34,29 +34,30 @@
* @param icon The icon to show on the button.
* @param text The text to show on the button.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/